@@ -16,7 +16,7 @@
 import os
 import sys
 import warnings
-from pkg_resources import parse_version
+from unittest import mock
 
 import setuptools  # force import setuptools before any other distutils imports
 
@@ -25,24 +25,14 @@ from buildbot.test.util.warnings import assertProducesWarning  # noqa pylint: di
 from buildbot.test.util.warnings import assertProducesWarnings  # noqa pylint: disable=wrong-import-position
 from buildbot.warnings import DeprecatedApiWarning  # noqa pylint: disable=wrong-import-position
 
-# import mock so we bail out early if it's not installed
-try:
-    import mock
-    [mock]
-except ImportError as e:
-    raise ImportError("\nBuildbot tests require the 'mock' module; "
-                      "try 'pip install mock'") from e
+[mock]
 
 # apply the same patches the buildmaster does when it starts
-monkeypatches.patch_all(for_tests=True)
+monkeypatches.patch_all()
 
 # enable deprecation warnings
 warnings.filterwarnings('always', category=DeprecationWarning)
 
-if parse_version(mock.__version__) < parse_version("0.8"):
-    raise ImportError("\nBuildbot tests require mock version 0.8.0 or "
-                      "higher; try 'pip install -U mock'")
-
 [setuptools]  # force use for pylint
 
 # This is where we load deprecated module-level APIs to ignore warning produced by importing them.
@@ -115,12 +105,6 @@ warnings.filterwarnings('ignore', ".*time.clock has been deprecated in Python 3.
 warnings.filterwarnings('ignore', ".*The usage of `cmp` is deprecated and will be removed "
                                   "on or after.*", DeprecationWarning)
 
-# ignore a warning emitted by pkg_resources when importing certain namespace packages
-warnings.filterwarnings('ignore', ".*Not importing directory .*/zope: missing __init__",
-                        category=ImportWarning)
-warnings.filterwarnings('ignore', ".*Not importing directory .*/sphinxcontrib: missing __init__",
-                        category=ImportWarning)
-
 # ignore warnings from importing lib2to3 via buildbot_pkg ->
 # setuptools.command.build_py -> setuptools.lib2to3_ex -> lib2to3
 # https://github.com/pypa/setuptools/issues/2086
@@ -143,3 +127,11 @@ warnings.filterwarnings('ignore', ".*'urllib3.contrib.pyopenssl' module is depre
 # pipes is still used in astroid and buildbot_worker in default installation
 warnings.filterwarnings('ignore', "'pipes' is deprecated and slated for removal in Python 3.13",
                         category=DeprecationWarning)
+
+# shown on Python 3.7 on Windows
+warnings.filterwarnings('ignore', "SelectableGroups dict interface is deprecated. Use select.",
+                        category=DeprecationWarning)
+
+# boto3 shows this warning when on old Python
+warnings.filterwarnings('ignore', ".*Boto3 will no longer support Python .*",
+                        category=Warning)
